---
layout: page
title: Assignment Portfolio
description: Overview of Assignment Portfolio (particularly the Group Assignments) and policies for report writing, directory structure and code documentation.
nav_order: 4
nav_exclude: false
permalink: /portfolio/
# math: mathjax
---
# Group Assignments

Overview of projects and module policies for report writing, directory structure and code documentation.

Group Assignments consist of the following elements:
1. A set of digitial files in the form of a working directory that you work on with your group members and submit every Friday at the end of the in-class sessions.
2. BuddyCheck, a weekly questionnaire administered via Brightspace to evaluate yourself and your group members.
3. Weekly reflections to improve the performance of your group and keep issues from becoming serious; recommended to occur at the beginning of the Wednesday in-class sessions, but this can be flexible.  






## Programming Assignments (PA)

A Programming Assignment is provided each week to introduce a few relevant concepts that are expected to be applied directly in the Group Assignment for that week. Programming Assignments are automatically graded after submitting them to GitLab and are assessed on a pass/no pass basis. You may resubmit as many times as needed to pass the assignment before the deadline at the end of each quarter (see the [Assignment Portfolio page](../portfolio) for deadlines).

You do not have to submit PA 1.1 and 1.2.

<!-- We will use a _static check_ to evaluate your work on a regular basis. This involves the teaching team making a clone of your repository and checking to see if you have met a few basic requirements. For example, did you use the right file name, and does your notebook run without error? These criteria will be specified for each assignment, and if you did not meet the criteria, you will get a report in a `static_check.md` file notifying you of any issues. We will make every attempt to run the static checks for the Programming Assignments every Monday, Wednesday and Friday at 8:45; however, depending on personnel, the times will be somewhat irregular. For practical purposes, you can assume that if your assignment is ready by 8:45 on Monday, Wednesday or Friday it will be checked by the end of the day. -->

<!-- All Programming Assignments for a given quarter will be checked on Monday, Wednesday and Friday, until the last check of the quarter, which will be the **Monday of week 9**. At this point, you will get full credit (2.5 pts) for all Programming Assignments that have passed the static check. See the point breakdown on the [Project page](../projects) for how the Programming Assignments are included in the Project Portfolio. -->

<!-- **Note about deadlines:** the times specified for the static are the _earliest_ time at which we will collect your work; it is your responsibility to make sure that your work is pushed to GitLab by this time, or you risk the chance of it not being checked until the next run. If you have made changes to your repository and the feedback in the static check file does not make sense, make sure you look at the time and day when it was run last, to see if your updates were actually taken into account. -->

## Projects (P)

Described on the [Project page](../projects).


### Assignment Portfolio

The Assignment Portfolio consists of three parts:
- Group Assignments (80%) and Programming Assignments (20%). Note that the BuddyChecks are also required and make up 10% of the Group Assignments (10% overall MUDE grade). The ultimate deadline to submit all of the components of the Assignment Portfolio is the last Friday of instruction for the quarter (week 8) at 12:30 (the end of the last Friday classroom session). Please note, however, that a consistent weekly schedule has been incorporated into the course activities, in particular: bi-weekly feedback on the Group Assignment reports and weekly grading of the Programming Assignments. In addition, failure to cooperate with your group members may result in the requirement that you submit the Group Assignments individually. Please see the relevant pages on this website for further details.







## Assessment

Each project is assessed on four categories using a discrete set of numeric criteria (4) for each, described in the sections below, with the total grade computed as a weighted sum. Every project receives equal weight, except Project 1, which is not included in the grade. 

### Deadlines for Feedback

Feedback will be provided during the week after each project submission, and will be based on the files you submit via your GitLab repository. 
- The deadline for submission is always Friday, 12:30 during the second week (although you can edit your GitLab repository until 13:30 to take care of technical issues, for example, fixing a merge conflict or uploading a file). Edits after that time will not be used for grading (this will be applied strictly starting with Project 4; Project 3 is an exception).
- Some groups may be asked to make some changes based on the static check, but you will be only allowed to fix the issues reported in the `static_check.md`.

Regarding questions about when you are allowed to make changes to your files:
- You are _always_ allowed to continue working on your files, and to ask teachers about the content (this is highly encouraged!).
- You are _not allowed_ to make changes to the answers and technical content (theory and code) of your files after Friday at 12:30 during the second week.

We will use a _static check_ to evaluate your work after each Friday session. This involves the teaching team making a clone of your repository and checking to see if you have met a few basic requirements. For example, did you use the right file name, and does your notebook run without error? These criteria will be specified for each assignment, and if you did not meet the criteria, you will get a report in a `static_check.md` file notifying you of any issues.

> Students that are just joining the Q2 projects as part of the completion of a previous year of MUDE are strongly encouraged to work through programming assignments PA03 and PA04 which introduce tips on how we encourage groups collaborate using _GitLab_. 

### Grading Categories

* **Documentation:** Readable and well-structured presentation of your results.
* **Application:** Project specifications have been met and demonstrated.
* **Programming:** Ensure that the implementation adequately commented and clear.
* **Interpretation:** Findings reported based on good evidence and sound reasoning with good eng/sci insight displayed.

Additional details about each grading category will be specified in the project description, and will be cumulative throughout the semester (especially for programming and documentation). For example, ifc week 1 focuses on using markdown cells and week 2 focuses on well-formatted figures as part of Project 1, you will be expected to produce markdown cells and well-formatted formatted figures in addition to the items specified in Project 2 during weeks 3 and 4.



### Grading Criteria: Individual Project Reports

> Updated for Q2 (Q1 used equal weights for each category)

| Category | No Submission | Insufficient | Sufficient | Very good | Default Weight |
|:------------:|:---:|:---:|:---:|:---:|:---:|
| Documentation  | 0 | 1 | 3 | 5 | **0.15** |
| Application  | 0 | 1 | 3 | 5 | **0.15** |
| Programming  | 0 | 1 | 3 | 5 | **0.15** |
| Interpretation  | 0 | 1 | 3 | 5 | **0.55** |

This default assessment weight will be applied for each category, but this may vary based on the project. If different, actual weights will be specified in the project description.

In general, we will expect you to submit a `Report.md` in markdown format. This file should be well-formatted with figures and text as necessary and any auxiliary files (like images) in a sub-directory. This document should summarize all findings in a clear and concise manner and will be the primary assessment piece. The `*.ipynb` will be checked to see how the findings have been determined. 


### Grading Criteria: Project Portfolio

The Project Portfolio will be determined based on a 200 point scale, which consists of the following elements:
- Projects: Generally speaking, 10 points per week; projects are graded for a max. of 140 points (Project 1 excluded).
- Programming Assignments: 2.5 points each for a maximum of 35 points (PA01 and PA02 not graded). 
- Buddycheck: 2 points each for a maximum of 12 points (Projects 1 and 2 not included).
- Free points: 13
- Total: 200 points

Because the projects are graded with a coarse +/-2 point scale, and the objective is to give you quick feedback about your progress for the week, the project portfolio grades are allocated using a discrete scale, as illustrated in the following table: 

| Project Portfolio Grade | Points |
| :---: | :---: |
| <5.0 | <104 |
| 5.0 | 104--123 |
| 6.5 | 124--145 |
| 7.5 | 146--161 |
| 8.5 | 162--171 |
| 9.0 | 172--181 |
| 9.5 | 182--191 |
| 10.0 | 192--200 |

### Peer Feedback with Buddycheck

*Buddycheck* is a learning tool designed to help peer evaluation amongst your group in a constructive and transparent way. A Buddycheck form must be submitted every week (you will recieve an announcement via Brightspace).

In addition to providing an opportunity for you to reflect on the performance of your group, and your role therein, the MUDE team will monitor the results and help guide those that may not be contributing in a productive and/or conscientious way. MUDE instructors may reach out to groups or individuals throughout the module, if necessary, and may alter the terms of projects for individuals. If after an initial warning, a second warning is issued, it may elicit in removal from the group, and the project portfolio for that quarter must be [completed individually](#as-an-individual-student).

## Documentation: Group Assignment Reports

There are a number of requirements that will be enforced for the **Project Reports**, which will be submitted as a combination of **Jupyter Notebooks**, **Python** and **Markdown** files. While providing the capability to present a wide variety of rich formatting, as well as facilitating computation, it is easy to produce documents that are simply un-readable --- these reporting requirements are designed to prevent that. Despite being part of your project grade, these are generally good practices, and you will benefit by getting into the habit of applying these (and the [Golden Rules](../golden-rules)) in your daily practice. 

To help you get familiar with notebooks and how they can be used to write readable reports, we will slowly introduce concepts to you throughout the module. For example, the project during weeks 1 and 2 will give you a mostly-completed notebook to start with, whereas by the end of Q2 you will be creating your own notebooks from scratch.

We will go deeper into the expectations and requirements as the module progresses. 

## Procedures and Conduct

### As a Group

Option 1 (default---and strongly recommended!)
* submit each project report as specified (generally each Friday at 12:30) and participate fairly with your group and you will receive timely feedback and keep up with the course contents

Option 2: you don't submit a project (or are unable to do so for any valid reason)
* notify instructors as soon as possible that you are not able to submit a project

If you receive an insufficient score for a single project you are not allowed an opportunity to repair this, unless you also have an insufficient for the entire Q1 or Q2 project portfolio.

If you receive an insufficient (<5.8) for the Project Portfolio (both quarters combined), you must notify the instructors that you would like to do a resit prior to the first day of the 3rd quarter. A new assignment and timeline will be communicated to you shortly thereafter; this approach will result in maximum grade of 6.0 for the Project Portfolio.

### As an Individual Student

Students that have been removed from their group for any reason will complete the project portfolio for that quarter individually. This can be done in either quarter, with a maximum grade of 6.0. Completing the project portfolio in one quarter does not preclude participating in a group and receiving the group grade for the other quarter. The assignment scope and timeline will be communicated to you on a case-by-case basis.

### Students from Previous Years

You may find it useful to specifically review *Programming assignments PA03 and PA04* that concern the usage of Git into the projects and effective collaboration. If you did not follow the Git tutorial last year, you may find this a little confusing to navigate, so it may be worthwhile reviewing these and mentioning this to your project team.   
